// Lean compiler output
// Module: Init.Data.Format.Macro
// Imports: Init.Data.Format.Basic Init.Data.ToString.Macro
#include <lean/lean.h>
#if defined(__clang__)
#pragma clang diagnostic ignored "-Wunused-parameter"
#pragma clang diagnostic ignored "-Wunused-label"
#elif defined(__GNUC__) && !defined(__CLANG__)
#pragma GCC diagnostic ignored "-Wunused-parameter"
#pragma GCC diagnostic ignored "-Wunused-label"
#pragma GCC diagnostic ignored "-Wunused-but-set-variable"
#endif
#ifdef __cplusplus
extern "C" {
#endif
static lean_object* l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__8;
static lean_object* l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__13;
static lean_object* l_Std_termF_x21_____closed__3;
static lean_object* l_Std_termF_x21_____closed__9;
static lean_object* l_Std_termF_x21_____closed__5;
static lean_object* l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__7;
static lean_object* l_Std_termF_x21_____closed__8;
lean_object* l_Lean_TSyntax_expandInterpolatedStr(lean_object*, lean_object*, lean_object*, lean_object*, lean_object*);
static lean_object* l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__15;
static lean_object* l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__5;
static lean_object* l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__6;
LEAN_EXPORT lean_object* l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1(lean_object*, lean_object*, lean_object*);
uint8_t l_Lean_Syntax_isOfKind(lean_object*, lean_object*);
static lean_object* l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__3;
static lean_object* l_Std_termF_x21_____closed__11;
static lean_object* l_Std_termF_x21_____closed__7;
static lean_object* l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__12;
lean_object* l_Lean_Name_mkStr3(lean_object*, lean_object*, lean_object*);
static lean_object* l_Std_termF_x21_____closed__12;
static lean_object* l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__0;
lean_object* l_Lean_SourceInfo_fromRef(lean_object*, uint8_t);
static lean_object* l_Std_termF_x21_____closed__14;
static lean_object* l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__4;
lean_object* l_Lean_addMacroScope(lean_object*, lean_object*, lean_object*);
lean_object* l_Lean_Syntax_getArg(lean_object*, lean_object*);
static lean_object* l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__14;
static lean_object* l_Std_termF_x21_____closed__6;
static lean_object* l_Std_termF_x21_____closed__0;
static lean_object* l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__11;
static lean_object* l_Std_termF_x21_____closed__1;
static lean_object* l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__2;
static lean_object* l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__1;
lean_object* l_Lean_Name_mkStr2(lean_object*, lean_object*);
static lean_object* l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__9;
static lean_object* l_Std_termF_x21_____closed__4;
static lean_object* l_Std_termF_x21_____closed__13;
static lean_object* l_Std_termF_x21_____closed__2;
static lean_object* l_Std_termF_x21_____closed__10;
lean_object* l_Lean_Name_mkStr1(lean_object*);
LEAN_EXPORT lean_object* l_Std_termF_x21__;
lean_object* l_String_toSubstring_x27(lean_object*);
static lean_object* l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__10;
static lean_object* _init_l_Std_termF_x21_____closed__0() {
_start:
{
lean_object* x_1; 
x_1 = lean_mk_string_unchecked("Std", 3, 3);
return x_1;
}
}
static lean_object* _init_l_Std_termF_x21_____closed__1() {
_start:
{
lean_object* x_1; 
x_1 = lean_mk_string_unchecked("termF!_", 7, 7);
return x_1;
}
}
static lean_object* _init_l_Std_termF_x21_____closed__2() {
_start:
{
lean_object* x_1; lean_object* x_2; lean_object* x_3; 
x_1 = l_Std_termF_x21_____closed__1;
x_2 = l_Std_termF_x21_____closed__0;
x_3 = l_Lean_Name_mkStr2(x_2, x_1);
return x_3;
}
}
static lean_object* _init_l_Std_termF_x21_____closed__3() {
_start:
{
lean_object* x_1; 
x_1 = lean_mk_string_unchecked("andthen", 7, 7);
return x_1;
}
}
static lean_object* _init_l_Std_termF_x21_____closed__4() {
_start:
{
lean_object* x_1; lean_object* x_2; 
x_1 = l_Std_termF_x21_____closed__3;
x_2 = l_Lean_Name_mkStr1(x_1);
return x_2;
}
}
static lean_object* _init_l_Std_termF_x21_____closed__5() {
_start:
{
lean_object* x_1; 
x_1 = lean_mk_string_unchecked("f!", 2, 2);
return x_1;
}
}
static lean_object* _init_l_Std_termF_x21_____closed__6() {
_start:
{
lean_object* x_1; lean_object* x_2; 
x_1 = l_Std_termF_x21_____closed__5;
x_2 = lean_alloc_ctor(5, 1, 0);
lean_ctor_set(x_2, 0, x_1);
return x_2;
}
}
static lean_object* _init_l_Std_termF_x21_____closed__7() {
_start:
{
lean_object* x_1; 
x_1 = lean_mk_string_unchecked("interpolatedStr", 15, 15);
return x_1;
}
}
static lean_object* _init_l_Std_termF_x21_____closed__8() {
_start:
{
lean_object* x_1; lean_object* x_2; 
x_1 = l_Std_termF_x21_____closed__7;
x_2 = l_Lean_Name_mkStr1(x_1);
return x_2;
}
}
static lean_object* _init_l_Std_termF_x21_____closed__9() {
_start:
{
lean_object* x_1; 
x_1 = lean_mk_string_unchecked("term", 4, 4);
return x_1;
}
}
static lean_object* _init_l_Std_termF_x21_____closed__10() {
_start:
{
lean_object* x_1; lean_object* x_2; 
x_1 = l_Std_termF_x21_____closed__9;
x_2 = l_Lean_Name_mkStr1(x_1);
return x_2;
}
}
static lean_object* _init_l_Std_termF_x21_____closed__11() {
_start:
{
lean_object* x_1; lean_object* x_2; lean_object* x_3; 
x_1 = lean_unsigned_to_nat(0u);
x_2 = l_Std_termF_x21_____closed__10;
x_3 = lean_alloc_ctor(7, 2, 0);
lean_ctor_set(x_3, 0, x_2);
lean_ctor_set(x_3, 1, x_1);
return x_3;
}
}
static lean_object* _init_l_Std_termF_x21_____closed__12() {
_start:
{
lean_object* x_1; lean_object* x_2; lean_object* x_3; 
x_1 = l_Std_termF_x21_____closed__11;
x_2 = l_Std_termF_x21_____closed__8;
x_3 = lean_alloc_ctor(1, 2, 0);
lean_ctor_set(x_3, 0, x_2);
lean_ctor_set(x_3, 1, x_1);
return x_3;
}
}
static lean_object* _init_l_Std_termF_x21_____closed__13() {
_start:
{
lean_object* x_1; lean_object* x_2; lean_object* x_3; lean_object* x_4; 
x_1 = l_Std_termF_x21_____closed__12;
x_2 = l_Std_termF_x21_____closed__6;
x_3 = l_Std_termF_x21_____closed__4;
x_4 = lean_alloc_ctor(2, 3, 0);
lean_ctor_set(x_4, 0, x_3);
lean_ctor_set(x_4, 1, x_2);
lean_ctor_set(x_4, 2, x_1);
return x_4;
}
}
static lean_object* _init_l_Std_termF_x21_____closed__14() {
_start:
{
lean_object* x_1; lean_object* x_2; lean_object* x_3; lean_object* x_4; 
x_1 = l_Std_termF_x21_____closed__13;
x_2 = lean_unsigned_to_nat(1024u);
x_3 = l_Std_termF_x21_____closed__2;
x_4 = lean_alloc_ctor(3, 3, 0);
lean_ctor_set(x_4, 0, x_3);
lean_ctor_set(x_4, 1, x_2);
lean_ctor_set(x_4, 2, x_1);
return x_4;
}
}
static lean_object* _init_l_Std_termF_x21__() {
_start:
{
lean_object* x_1; 
x_1 = l_Std_termF_x21_____closed__14;
return x_1;
}
}
static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__0() {
_start:
{
lean_object* x_1; 
x_1 = lean_mk_string_unchecked("Format", 6, 6);
return x_1;
}
}
static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__1() {
_start:
{
lean_object* x_1; lean_object* x_2; 
x_1 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__0;
x_2 = l_String_toSubstring_x27(x_1);
return x_2;
}
}
static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__2() {
_start:
{
lean_object* x_1; lean_object* x_2; 
x_1 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__0;
x_2 = l_Lean_Name_mkStr1(x_1);
return x_2;
}
}
static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__3() {
_start:
{
lean_object* x_1; lean_object* x_2; lean_object* x_3; 
x_1 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__0;
x_2 = l_Std_termF_x21_____closed__0;
x_3 = l_Lean_Name_mkStr2(x_2, x_1);
return x_3;
}
}
static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__4() {
_start:
{
lean_object* x_1; lean_object* x_2; lean_object* x_3; 
x_1 = lean_box(0);
x_2 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__3;
x_3 = lean_alloc_ctor(1, 2, 0);
lean_ctor_set(x_3, 0, x_2);
lean_ctor_set(x_3, 1, x_1);
return x_3;
}
}
static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__5() {
_start:
{
lean_object* x_1; lean_object* x_2; 
x_1 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__3;
x_2 = lean_alloc_ctor(0, 1, 0);
lean_ctor_set(x_2, 0, x_1);
return x_2;
}
}
static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__6() {
_start:
{
lean_object* x_1; lean_object* x_2; lean_object* x_3; 
x_1 = lean_box(0);
x_2 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__5;
x_3 = lean_alloc_ctor(1, 2, 0);
lean_ctor_set(x_3, 0, x_2);
lean_ctor_set(x_3, 1, x_1);
return x_3;
}
}
static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__7() {
_start:
{
lean_object* x_1; lean_object* x_2; lean_object* x_3; 
x_1 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__6;
x_2 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__4;
x_3 = lean_alloc_ctor(1, 2, 0);
lean_ctor_set(x_3, 0, x_2);
lean_ctor_set(x_3, 1, x_1);
return x_3;
}
}
static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__8() {
_start:
{
lean_object* x_1; 
x_1 = lean_mk_string_unchecked("Std.format", 10, 10);
return x_1;
}
}
static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__9() {
_start:
{
lean_object* x_1; lean_object* x_2; 
x_1 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__8;
x_2 = l_String_toSubstring_x27(x_1);
return x_2;
}
}
static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__10() {
_start:
{
lean_object* x_1; 
x_1 = lean_mk_string_unchecked("format", 6, 6);
return x_1;
}
}
static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__11() {
_start:
{
lean_object* x_1; lean_object* x_2; lean_object* x_3; 
x_1 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__10;
x_2 = l_Std_termF_x21_____closed__0;
x_3 = l_Lean_Name_mkStr2(x_2, x_1);
return x_3;
}
}
static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__12() {
_start:
{
lean_object* x_1; 
x_1 = lean_mk_string_unchecked("ToFormat", 8, 8);
return x_1;
}
}
static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__13() {
_start:
{
lean_object* x_1; lean_object* x_2; lean_object* x_3; lean_object* x_4; 
x_1 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__10;
x_2 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__12;
x_3 = l_Std_termF_x21_____closed__0;
x_4 = l_Lean_Name_mkStr3(x_3, x_2, x_1);
return x_4;
}
}
static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__14() {
_start:
{
lean_object* x_1; lean_object* x_2; lean_object* x_3; 
x_1 = lean_box(0);
x_2 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__13;
x_3 = lean_alloc_ctor(1, 2, 0);
lean_ctor_set(x_3, 0, x_2);
lean_ctor_set(x_3, 1, x_1);
return x_3;
}
}
static lean_object* _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__15() {
_start:
{
lean_object* x_1; lean_object* x_2; lean_object* x_3; 
x_1 = lean_box(0);
x_2 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__14;
x_3 = lean_alloc_ctor(1, 2, 0);
lean_ctor_set(x_3, 0, x_2);
lean_ctor_set(x_3, 1, x_1);
return x_3;
}
}
LEAN_EXPORT lean_object* l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1(lean_object* x_1, lean_object* x_2, lean_object* x_3) {
_start:
{
lean_object* x_4; uint8_t x_5; 
x_4 = l_Std_termF_x21_____closed__2;
lean_inc(x_1);
x_5 = l_Lean_Syntax_isOfKind(x_1, x_4);
if (x_5 == 0)
{
lean_object* x_6; lean_object* x_7; 
lean_dec_ref(x_2);
lean_dec(x_1);
x_6 = lean_box(1);
x_7 = lean_alloc_ctor(1, 2, 0);
lean_ctor_set(x_7, 0, x_6);
lean_ctor_set(x_7, 1, x_3);
return x_7;
}
else
{
lean_object* x_8; lean_object* x_9; lean_object* x_10; lean_object* x_11; lean_object* x_12; uint8_t x_13; lean_object* x_14; lean_object* x_15; lean_object* x_16; lean_object* x_17; lean_object* x_18; lean_object* x_19; lean_object* x_20; lean_object* x_21; lean_object* x_22; lean_object* x_23; lean_object* x_24; lean_object* x_25; 
x_8 = lean_ctor_get(x_2, 1);
x_9 = lean_ctor_get(x_2, 2);
x_10 = lean_ctor_get(x_2, 5);
x_11 = lean_unsigned_to_nat(1u);
x_12 = l_Lean_Syntax_getArg(x_1, x_11);
lean_dec(x_1);
x_13 = 0;
x_14 = l_Lean_SourceInfo_fromRef(x_10, x_13);
x_15 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__1;
x_16 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__2;
lean_inc(x_9);
lean_inc(x_8);
x_17 = l_Lean_addMacroScope(x_8, x_16, x_9);
x_18 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__7;
lean_inc(x_14);
x_19 = lean_alloc_ctor(3, 4, 0);
lean_ctor_set(x_19, 0, x_14);
lean_ctor_set(x_19, 1, x_15);
lean_ctor_set(x_19, 2, x_17);
lean_ctor_set(x_19, 3, x_18);
x_20 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__9;
x_21 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__11;
lean_inc(x_9);
lean_inc(x_8);
x_22 = l_Lean_addMacroScope(x_8, x_21, x_9);
x_23 = l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__15;
x_24 = lean_alloc_ctor(3, 4, 0);
lean_ctor_set(x_24, 0, x_14);
lean_ctor_set(x_24, 1, x_20);
lean_ctor_set(x_24, 2, x_22);
lean_ctor_set(x_24, 3, x_23);
x_25 = l_Lean_TSyntax_expandInterpolatedStr(x_12, x_19, x_24, x_2, x_3);
lean_dec(x_12);
if (lean_obj_tag(x_25) == 0)
{
uint8_t x_26; 
x_26 = !lean_is_exclusive(x_25);
if (x_26 == 0)
{
return x_25;
}
else
{
lean_object* x_27; lean_object* x_28; lean_object* x_29; 
x_27 = lean_ctor_get(x_25, 0);
x_28 = lean_ctor_get(x_25, 1);
lean_inc(x_28);
lean_inc(x_27);
lean_dec(x_25);
x_29 = lean_alloc_ctor(0, 2, 0);
lean_ctor_set(x_29, 0, x_27);
lean_ctor_set(x_29, 1, x_28);
return x_29;
}
}
else
{
uint8_t x_30; 
x_30 = !lean_is_exclusive(x_25);
if (x_30 == 0)
{
return x_25;
}
else
{
lean_object* x_31; lean_object* x_32; lean_object* x_33; 
x_31 = lean_ctor_get(x_25, 0);
x_32 = lean_ctor_get(x_25, 1);
lean_inc(x_32);
lean_inc(x_31);
lean_dec(x_25);
x_33 = lean_alloc_ctor(1, 2, 0);
lean_ctor_set(x_33, 0, x_31);
lean_ctor_set(x_33, 1, x_32);
return x_33;
}
}
}
}
}
lean_object* initialize_Init_Data_Format_Basic(uint8_t builtin, lean_object*);
lean_object* initialize_Init_Data_ToString_Macro(uint8_t builtin, lean_object*);
static bool _G_initialized = false;
LEAN_EXPORT lean_object* initialize_Init_Data_Format_Macro(uint8_t builtin, lean_object* w) {
lean_object * res;
if (_G_initialized) return lean_io_result_mk_ok(lean_box(0));
_G_initialized = true;
res = initialize_Init_Data_Format_Basic(builtin, lean_io_mk_world());
if (lean_io_result_is_error(res)) return res;
lean_dec_ref(res);
res = initialize_Init_Data_ToString_Macro(builtin, lean_io_mk_world());
if (lean_io_result_is_error(res)) return res;
lean_dec_ref(res);
l_Std_termF_x21_____closed__0 = _init_l_Std_termF_x21_____closed__0();
lean_mark_persistent(l_Std_termF_x21_____closed__0);
l_Std_termF_x21_____closed__1 = _init_l_Std_termF_x21_____closed__1();
lean_mark_persistent(l_Std_termF_x21_____closed__1);
l_Std_termF_x21_____closed__2 = _init_l_Std_termF_x21_____closed__2();
lean_mark_persistent(l_Std_termF_x21_____closed__2);
l_Std_termF_x21_____closed__3 = _init_l_Std_termF_x21_____closed__3();
lean_mark_persistent(l_Std_termF_x21_____closed__3);
l_Std_termF_x21_____closed__4 = _init_l_Std_termF_x21_____closed__4();
lean_mark_persistent(l_Std_termF_x21_____closed__4);
l_Std_termF_x21_____closed__5 = _init_l_Std_termF_x21_____closed__5();
lean_mark_persistent(l_Std_termF_x21_____closed__5);
l_Std_termF_x21_____closed__6 = _init_l_Std_termF_x21_____closed__6();
lean_mark_persistent(l_Std_termF_x21_____closed__6);
l_Std_termF_x21_____closed__7 = _init_l_Std_termF_x21_____closed__7();
lean_mark_persistent(l_Std_termF_x21_____closed__7);
l_Std_termF_x21_____closed__8 = _init_l_Std_termF_x21_____closed__8();
lean_mark_persistent(l_Std_termF_x21_____closed__8);
l_Std_termF_x21_____closed__9 = _init_l_Std_termF_x21_____closed__9();
lean_mark_persistent(l_Std_termF_x21_____closed__9);
l_Std_termF_x21_____closed__10 = _init_l_Std_termF_x21_____closed__10();
lean_mark_persistent(l_Std_termF_x21_____closed__10);
l_Std_termF_x21_____closed__11 = _init_l_Std_termF_x21_____closed__11();
lean_mark_persistent(l_Std_termF_x21_____closed__11);
l_Std_termF_x21_____closed__12 = _init_l_Std_termF_x21_____closed__12();
lean_mark_persistent(l_Std_termF_x21_____closed__12);
l_Std_termF_x21_____closed__13 = _init_l_Std_termF_x21_____closed__13();
lean_mark_persistent(l_Std_termF_x21_____closed__13);
l_Std_termF_x21_____closed__14 = _init_l_Std_termF_x21_____closed__14();
lean_mark_persistent(l_Std_termF_x21_____closed__14);
l_Std_termF_x21__ = _init_l_Std_termF_x21__();
lean_mark_persistent(l_Std_termF_x21__);
l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__0 = _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__0();
lean_mark_persistent(l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__0);
l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__1 = _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__1();
lean_mark_persistent(l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__1);
l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__2 = _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__2();
lean_mark_persistent(l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__2);
l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__3 = _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__3();
lean_mark_persistent(l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__3);
l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__4 = _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__4();
lean_mark_persistent(l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__4);
l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__5 = _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__5();
lean_mark_persistent(l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__5);
l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__6 = _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__6();
lean_mark_persistent(l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__6);
l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__7 = _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__7();
lean_mark_persistent(l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__7);
l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__8 = _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__8();
lean_mark_persistent(l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__8);
l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__9 = _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__9();
lean_mark_persistent(l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__9);
l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__10 = _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__10();
lean_mark_persistent(l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__10);
l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__11 = _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__11();
lean_mark_persistent(l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__11);
l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__12 = _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__12();
lean_mark_persistent(l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__12);
l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__13 = _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__13();
lean_mark_persistent(l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__13);
l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__14 = _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__14();
lean_mark_persistent(l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__14);
l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__15 = _init_l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__15();
lean_mark_persistent(l_Std___aux__Init__Data__Format__Macro______macroRules__Std__termF_x21____1___closed__15);
return lean_io_result_mk_ok(lean_box(0));
}
#ifdef __cplusplus
}
#endif
